bayespy.inference.vmp.nodes.gaussian_markov_chain.SwitchingGaussianMarkovChainDistribution
==========================================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.gaussian_markov_chain

.. autoclass:: SwitchingGaussianMarkovChainDistribution

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
      :toctree: generated/
   
      ~SwitchingGaussianMarkovChainDistribution.__init__
      ~SwitchingGaussianMarkovChainDistribution.compute_cgf_from_parents
      ~SwitchingGaussianMarkovChainDistribution.compute_fixed_moments_and_f
      ~SwitchingGaussianMarkovChainDistribution.compute_gradient
      ~SwitchingGaussianMarkovChainDistribution.compute_logpdf
      ~SwitchingGaussianMarkovChainDistribution.compute_message_to_parent
      ~SwitchingGaussianMarkovChainDistribution.compute_moments_and_cgf
      ~SwitchingGaussianMarkovChainDistribution.compute_phi_from_parents
      ~SwitchingGaussianMarkovChainDistribution.compute_weights_to_parent
      ~SwitchingGaussianMarkovChainDistribution.plates_from_parent
      ~SwitchingGaussianMarkovChainDistribution.plates_to_parent
      ~SwitchingGaussianMarkovChainDistribution.random
   
   

   
   
   